..
    Copyright (C) 2021 CERN.

    Invenio-Requests is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 1.0.3 (released 2022-11-15)

- add `indexer_queue_name` property in service configs
- add the services and indexers in global registry

Version 1.0.2 (released 2022-11-04)

- bump invenio-records-resources version

Version 1.0.1 (released 2022-11-03)

- add mobile components styling

Version 1.0.0

- Initial public release.
